@@ -1,7 +1,7 @@
 /* SPDX-License-Identifier: GPL-2.0-or-later
 
 Copyright (C) 2014  Vyacheslav Trushkin
-Copyright (C) 2020-2025  Boian Bonev
+Copyright (C) 2020-2026  Boian Bonev
 
 This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 
@@ -30,7 +30,7 @@ You should have received a copy of the GNU General Public License along with thi
 
 #include "ucell.h"
 
-#define VERSION "1.29"
+#define VERSION "1.31"
 
 typedef enum {
 	E_GR_IO,
@@ -96,6 +96,7 @@ extern params_t params;
 extern int maxpidlen;
 extern unsigned taskstats_ver;
 
+#define IOTOP_TASKSTATS_MINVER 4
 #define IOTOP_TASKSTATS_VERSION 15
 
 #define HISTORY_POS 60
@@ -143,8 +144,9 @@ struct xxxid_stats {
 	int io_prio;
 
 	int euid;
-	char *cmdline1;
-	char *cmdline2;
+	char *cmdline_long;
+	char *cmdline_short;
+	char *cmdline_comm;
 	char *pw_name;
 
 	uint8_t iohist[HISTORY_CNT]; // io history data
@@ -210,7 +212,7 @@ inline int masked_sort_by(int isforward);
 
 /* utils.c */
 
-inline char *read_cmdline(int pid,int isshort);
+inline void read_cmdlines(int pid,char **cmd_long,char **cmd_short,char **cmd_comm);
 
 inline int64_t monotime(void);
 inline char *u8strpadt(const char *s,ssize_t len);
